@@ -1,4 +1,4 @@
-# Copyright (c) 2008-2015 MetPy Developers.
+# Copyright (c) 2008,2015,2016,2017 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
 """Contains a collection of thermodynamic calculations."""
@@ -274,28 +274,16 @@ def el(pressure, temperature, dewpt):
 
     """
     ideal_profile = parcel_profile(pressure, temperature[0], dewpt[0]).to('degC')
-    x, y = find_intersections(pressure[1:], ideal_profile[1:], temperature[1:])
-    # Find LFC to make sure that the function isn't passing off the LFC as the EL
-    lfc_pressure, _ = lfc(pressure, temperature, dewpt)
+    # If the top of the sounding parcel is warmer than the environment, there is no EL
+    if ideal_profile[-1] > temperature[-1]:
+        return np.nan * pressure.units, np.nan * temperature.units
 
-    # If there is only one intersection, there are two possibilities:
-    # the dataset does not contain the EL, or the LFC = LCL.
-    if len(x) <= 1:
-        if (ideal_profile[-1] < temperature[-1]) and (len(x) == 1):
-            # Profile top colder than environment with one
-            # intersection, EL exists and LFC = LCL
-            return x[-1], y[-1]
-        else:
-            # The EL does not exist, either due to incomplete data
-            # or no intersection occurring.
-            return np.nan * pressure.units, np.nan * temperature.units
+    # Otherwise the last intersection (as long as there is one) is the EL
+    x, y = find_intersections(pressure[1:], ideal_profile[1:], temperature[1:])
+    if len(x) > 0:
+        return x[-1], y[-1]
     else:
-        # Checking to make sure the LFC is not returned as the EL
-        # when data is truncated below the EL
-        if np.isclose(x[-1], lfc_pressure, atol=1e-6):
-            return np.nan * pressure.units, np.nan * temperature.units
-        else:
-            return x[-1], y[-1]
+        return np.nan * pressure.units, np.nan * temperature.units
 
 
 @exporter.export
@@ -328,16 +316,16 @@ def parcel_profile(pressure, temperature, dewpt):
 
     """
     # Find the LCL
-    l = lcl(pressure[0], temperature, dewpt)[0].to(pressure.units)
+    lcl_pressure = lcl(pressure[0], temperature, dewpt)[0].to(pressure.units)
 
     # Find the dry adiabatic profile, *including* the LCL. We need >= the LCL in case the
     # LCL is included in the levels. It's slightly redundant in that case, but simplifies
     # the logic for removing it later.
-    press_lower = concatenate((pressure[pressure >= l], l))
+    press_lower = concatenate((pressure[pressure >= lcl_pressure], lcl_pressure))
     t1 = dry_lapse(press_lower, temperature)
 
     # Find moist pseudo-adiabatic profile starting at the LCL
-    press_upper = concatenate((l, pressure[pressure < l]))
+    press_upper = concatenate((lcl_pressure, pressure[pressure < lcl_pressure]))
     t2 = moist_lapse(press_upper, t1[-1]).to(t1.units)
 
     # Return LCL *without* the LCL point
@@ -975,22 +963,18 @@ def cape_cin(pressure, temperature, dewpt, parcel_profile):
     # Estimate zero crossings
     x, y = _find_append_zero_crossings(np.copy(pressure), y)
 
-    # CAPE (temperature parcel < temperature environment)
+    # CAPE
     # Only use data between the LFC and EL for calculation
     p_mask = _less_or_close(x, lfc_pressure) & _greater_or_close(x, el_pressure)
     x_clipped = x[p_mask]
     y_clipped = y[p_mask]
-
-    y_clipped[_less_or_close(y_clipped, 0 * units.degK)] = 0 * units.degK
     cape = (Rd * (np.trapz(y_clipped, np.log(x_clipped)) * units.degK)).to(units('J/kg'))
 
-    # CIN (temperature parcel < temperature environment)
+    # CIN
     # Only use data between the surface and LFC for calculation
     p_mask = _greater_or_close(x, lfc_pressure)
     x_clipped = x[p_mask]
     y_clipped = y[p_mask]
-
-    y_clipped[_greater_or_close(y_clipped, 0 * units.degK)] = 0 * units.degK
     cin = (Rd * (np.trapz(y_clipped, np.log(x_clipped)) * units.degK)).to(units('J/kg'))
 
     return cape, cin
