@@ -1,4 +1,4 @@
-# Copyright (c) 2008-2015 MetPy Developers.
+# Copyright (c) 2014,2015,2016,2017 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
 """Make Skew-T Log-P based plots.
@@ -7,6 +7,7 @@ Contain tools for making Skew-T Log-P plots, including the base plotting class,
 `SkewT`, as well as a class for making a `Hodograph`.
 """
 
+import matplotlib
 from matplotlib.axes import Axes
 import matplotlib.axis as maxis
 from matplotlib.collections import LineCollection
@@ -22,7 +23,7 @@ from ._util import colored_line
 from ..calc import dewpoint, dry_lapse, moist_lapse, vapor_pressure
 from ..calc.tools import delete_masked_points, interp
 from ..package_tools import Exporter
-from ..units import units
+from ..units import concatenate, units
 
 exporter = Exporter(globals())
 
@@ -314,7 +315,7 @@ class SkewT(object):
         """
         # Skew-T logP plotting
         t, p = delete_masked_points(t, p)
-        l = self.ax.semilogy(t, p, *args, **kwargs)
+        lines = self.ax.semilogy(t, p, *args, **kwargs)
 
         # Disables the log-formatting that comes with semilogy
         self.ax.yaxis.set_major_formatter(ScalarFormatter())
@@ -326,7 +327,7 @@ class SkewT(object):
         # Try to make sane default temperature plotting
         self.ax.xaxis.set_major_locator(MultipleLocator(10))
 
-        return l
+        return lines
 
     def plot_barbs(self, p, u, v, c=None, xloc=1.0, x_clip_radius=0.08,
                    y_clip_radius=0.08, **kwargs):
@@ -590,6 +591,9 @@ class SkewT(object):
             arrs = arrs + (fill_args['where'],)
             fill_args.pop('where', None)
 
+        if matplotlib.__version__ >= '2.1':
+            fill_args['interpolate'] = True
+
         arrs = delete_masked_points(*arrs)
 
         return self.ax.fill_betweenx(*arrs, **fill_args)
@@ -812,15 +816,18 @@ class Hodograph(object):
         """
         u, v, c = delete_masked_points(u, v, c)
 
+        # Plotting a color segmented hodograph
         if colors:
             cmap = mcolors.ListedColormap(colors)
+            # If we are segmenting by height (a length), interpolate the bounds
             if bounds.dimensionality == {'[length]': 1.0}:
-                bounds = np.asarray(bounds + c[0]) * bounds.units
-                interp_vert = interp(bounds, c, c, u, v)
-                inds = np.searchsorted(c.magnitude, bounds.magnitude)
-                u = np.insert(u.magnitude, inds, interp_vert[1].magnitude)
-                v = np.insert(v.magnitude, inds, interp_vert[2].magnitude)
-                c = np.insert(c.magnitude, inds, interp_vert[0].magnitude)
+                bounds = bounds + c[0]  # Make all heights AGL
+                interpolation_heights = concatenate((bounds, c))
+                interpolation_heights = (np.sort(interpolation_heights) *
+                                         interpolation_heights.units)
+                c, u, v = interp(interpolation_heights, c, c, u, v)
+                c = c.to_base_units()  # TODO: This shouldn't be required!
+            # If segmenting by anything else, do not interpolate, just use the data
             else:
                 bounds = np.asarray(bounds) * bounds.units
 
@@ -830,8 +837,12 @@ class Hodograph(object):
             kwargs['cmap'] = cmap
             kwargs['norm'] = norm
             line_args = self._form_line_args(kwargs)
+
+        # Plotting a continuously colored line
         else:
             line_args = self._form_line_args(kwargs)
+
+        # Do the plotting
         lc = colored_line(u, v, c, **line_args)
         self.ax.add_collection(lc)
         return lc
